@@ -3,7 +3,7 @@ package Git::Code::Review::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '2.4'; # VERSION
+our $VERSION = '2.5'; # VERSION
 
 # Utility Modules
 use CLI::Helpers qw(:all);
@@ -47,6 +47,7 @@ use Sub::Exporter -setup => {
         gcr_audit_commit
         gcr_audit_files
         gcr_audit_record
+        gcr_get_states
         gcr_state_color
         gcr_lookup_profile
     )],
@@ -500,6 +501,12 @@ sub gcr_change_profile {
 
 
 
+sub gcr_get_states {
+    return keys %STATE;
+}
+
+
+
 sub gcr_change_state {
     my($commit,$state,$info) = @_;
     my $audit = gcr_repo();
@@ -832,7 +839,7 @@ Git::Code::Review::Utilities - Tools for performing code review using Git as the
 
 =head1 VERSION
 
-version 2.4
+version 2.5
 
 =head1 FUNCTIONS
 
@@ -920,6 +927,10 @@ $details can be either a string, the commit message, or a hash reference
 including a 'message' item to become the commit message.  The rest of the keys
 will be added to the YAML generated.
 
+=head2 gcr_get_states()
+
+Get the valid states
+
 =head2 gcr_change_state($commit_info,$state,$details)
 
 $commit_info is a hash attained from gcr_commit_info()
